{% load cms_tags %}
<div class="{% if not grid.inner %}container-{{ GRID_SIZE }} {% endif %}clearfix">
{% for plugin in grid.child_plugin_instances %}
  	{% render_plugin plugin %}
{% endfor %}
</div>